@@ -319,6 +319,87 @@ def resize_image_url(
         return full_storage_url
 
 
+def get_storage_url(
+    entity_type: Literal["dataset-entities", "dataset", "project", "file-storage"],
+    entity_id: int,
+    source_type: Literal["original", "preview"],
+) -> str:
+    """
+    Generate URL for storage resources endpoints.
+
+    :param entity_type: Type of entity ("dataset-entities", "dataset", "project", "file-storage")
+    :type entity_type: str
+    :param entity_id: ID of the entity
+    :type entity_id: int
+    :param source_type: Type of source ("original" or "preview")
+    :type source_type: Literal["original", "preview"]
+    :return: Storage URL
+    :rtype: str
+    """
+    relative_url = f"/storage-resources/{entity_type}/{source_type}/{entity_id}"
+    if is_development():
+        return abs_url(relative_url)
+    return relative_url
+
+
+def get_image_storage_url(image_id: int, source_type: Literal["original", "preview"]) -> str:
+    """
+    Generate URL for image storage resources.
+
+    :param image_id: ID of the image
+    :type image_id: int
+    :param source_type: Type of source ("original" or "preview")
+    :type source_type: Literal["original", "preview"]
+    :return: Storage URL for image
+    :rtype: str
+    """
+    return get_storage_url("dataset-entities", image_id, source_type)
+
+
+def get_dataset_storage_url(
+    dataset_id: int, source_type: Literal["original", "preview", "raw"]
+) -> str:
+    """
+    Generate URL for dataset storage resources.
+
+    :param dataset_id: ID of the dataset
+    :type dataset_id: int
+    :param source_type: Type of source ("original", "preview", or "raw")
+    :type source_type: Literal["original", "preview", "raw"]
+    :return: Storage URL for dataset
+    :rtype: str
+    """
+    return get_storage_url("dataset", dataset_id, source_type)
+
+
+def get_project_storage_url(
+    project_id: int, source_type: Literal["original", "preview", "raw"]
+) -> str:
+    """
+    Generate URL for project storage resources.
+
+    :param project_id: ID of the project
+    :type project_id: int
+    :param source_type: Type of source ("original", "preview", or "raw")
+    :type source_type: Literal["original", "preview", "raw"]
+    :return: Storage URL for project
+    :rtype: str
+    """
+    return get_storage_url("project", project_id, source_type)
+
+
+def get_file_storage_url(file_id: int) -> str:
+    """
+    Generate URL for file storage resources (raw files).
+
+    :param file_id: ID of the file
+    :type file_id: int
+    :return: Storage URL for file
+    :rtype: str
+    """
+    return get_storage_url("file-storage", file_id, "raw")
+
+
 def get_preview_link(title="preview"):
     return (
         f'<a href="javascript:;">{title}<i class="zmdi zmdi-cast" style="margin-left: 5px"></i></a>'
