@@ -22,6 +22,7 @@ from supervisely.geometry.rectangle import Rectangle
 from supervisely.nn.inference.cache import InferenceImageCache
 from supervisely.sly_logger import logger
 from supervisely.video_annotation.key_id_map import KeyIdMap
+from supervisely.annotation.label import LabelingStatus
 
 
 class TrackerInterface:
@@ -166,6 +167,8 @@ class TrackerInterface:
                     ApiField.GEOMETRY: geometry.to_json(),
                     ApiField.META: {ApiField.FRAME: frame_index},
                     ApiField.TRACK_ID: self.track_id,
+                    ApiField.NN_CREATED: True,
+                    ApiField.NN_UPDATED: True,
                 }
                 for geometry, frame_index in geometries_frame_indexes
             ]
@@ -195,6 +198,7 @@ class TrackerInterface:
             geometry.to_json(),
             geometry.geometry_name(),
             self.track_id,
+            status=LabelingStatus.AUTO,
         )
         self.logger.debug(f"Added {geometry.geometry_name()} to frame #{frame_ind}")
         if notify:
